# Generated by Django 2.2.28 on 2022-12-21 03:14

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DjangoDBCounter',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(db_index=True, max_length=128, verbose_name='数据库计数器关键字')),
                ('add_time', models.DateTimeField(auto_now_add=True, verbose_name='Add Time')),
                ('mod_time', models.DateTimeField(auto_now=True, verbose_name='Modify Time')),
            ],
            options={
                'verbose_name': '数据库计数记录',
                'verbose_name_plural': '数据库计数记录',
            },
        ),
    ]
